<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: testEnvironment.php 2409 2005-04-07 14:28:24Z andrew $
*/

/**
 * @package    Max
 * @subpackage TestSuite
 * @author     Demian Turner <demian@awarez.net>
 * @author     Andrew Hill <andrew@awarez.net>
 */

/**
 * A class to allow the easy setup and take-down of the testing environment,
 * for both running individual files, and for running groups of test files.
 */
class testEnvironment
{
    var $first;
    var $database;
    var $dbNameBackup;
    var $startTime;
    
    /**
     * A method to set up the test environment.
     *
     * @param boolean $database Optional parameter to specify if the max_simpletest
     *                          database needs to be created in order to run the tests.
     * @param boolean $tables Optional parameter to specify if the max_simpletest
     *                        database, if created, should have all of the tables
     *                        used by Max created as well.
     */
    function init($database = false, $tables = false)
    {
        // Is this first time init has been called in a test run?
        static $globalFirst;
        if (!isset($globalFirst)) {
            $globalFirst = true;
            $this->first = true;
        } else {
            $this->first = false;
        }
        // Store the database requirement so it can be used later
        $this->database = $database;
        // Setup the Max environment
        require_once MAX_PATH . '/init.php';
        if ($this->database) {
            // Create the max_simpletest database, if required
            include_once MAX_PATH . '/lib/max/DB.php';
            $dbh = &MAX_DB::singleton();
            $query = "DROP DATABASE IF EXISTS max_simpletest";
            $result = $dbh->query($query);
            $query = "CREATE DATABASE max_simpletest";
            $result = $dbh->query($query);
            // Modify the Max environment so that it uses the max_simpletest database
            $this->dbNameBackup = $GLOBALS['_MAX']['CONF']['database']['name'];
            $GLOBALS['_MAX']['CONF']['database']['name'] = 'max_simpletest';
            if ($tables) {
                // Create all of the core tables
                include_once MAX_PATH . '/lib/max/Table/Core.php';
                $tables = &MAX_Table_Core::singleton();
                $tables->createAllTables();
            }
        }
        // If the first time init() has been called, set up for tests
        if ($this->first) {
            // Require the Simpletest files
            if (!defined('SIMPLE_TEST')) {
                define('SIMPLE_TEST', MAX_PATH . '/lib/simpletest');
            }
            require_once SIMPLE_TEST .'/unit_tester.php';
            require_once SIMPLE_TEST .'/mock_objects.php';
            require_once SIMPLE_TEST .'/reporter.php';
            require_once SIMPLE_TEST .'/web_tester.php';
            // Output the HTML header
            include_once MAX_PATH . '/tests/header.html';
            // Record the test start time
            $this->startTime = time();
        }
    }
    
    /**
     * A method to close off the test environment.
     */
    function deinit()
    {
        // If this test set up a database, drop it
        if ($this->database) {
            // Drop the max_simpletest database
            include_once MAX_PATH . '/lib/max/DB.php';
            $dbh = &MAX_DB::singleton();
            $query = "DROP DATABASE IF EXISTS max_simpletest";
            $result = $dbh->query($query);
            // Restore the database used
            $GLOBALS['_MAX']['CONF']['database']['name'] = $this->dbNameBackup;    
        }
        // If this test was the first to call init(), close off
        // the testing environment
        if ($this->first) {
            // Calculate and display the test run time
            $endTime = time();
            $time = $endTime - $this->startTime;
            echo '<p>Tests took ' . $time . ' seconds</p>';
            // Output the HTML footer
            include_once MAX_PATH . '/tests/footer.html';
        }
    }
    
}

?>
